==> haskell-hjsonschema-1.9.0-185-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonschema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonschema
version: 1.9.0
id: hjsonschema-1.9.0-9dIXUEq7rhKHCkAPW91zIX
key: hjsonschema-1.9.0-9dIXUEq7rhKHCkAPW91zIX
license: MIT
maintainer: ian@housejeffries.com
author: Ian Grant Jeffries
homepage: https://github.com/seagreen/hjsonschema
synopsis: JSON Schema library
category: Data
abi: 3b267292488155c3cf000c54b6db123b
exposed: True
exposed-modules:
    JSONSchema.Draft4 JSONSchema.Draft4.Failure
    JSONSchema.Draft4.Schema JSONSchema.Draft4.Spec JSONSchema.Fetch
    JSONSchema.Types JSONSchema.Validator.Draft4
    JSONSchema.Validator.Draft4.Any JSONSchema.Validator.Draft4.Array
    JSONSchema.Validator.Draft4.Number
    JSONSchema.Validator.Draft4.Object
    JSONSchema.Validator.Draft4.String JSONSchema.Validator.Reference
    JSONSchema.Validator.Types JSONSchema.Validator.Utils
hidden-modules: JSONSchema.Validator.Draft4.Object.Properties
                Import
import-dirs: /usr/lib/ghc-8.6.4/site-local/hjsonschema-1.9.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/hjsonschema-1.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hjsonschema-1.9.0
hs-libraries: HShjsonschema-1.9.0-9dIXUEq7rhKHCkAPW91zIX
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hjsonpointer-1.5.0-IfRLvsIWR69CLRRorzWBuv
    http-client-0.6.4-4eignF5HylU2BUpoDKITVq
    http-client-tls-0.3.5.3-ENbOqCF0gxIB9PpdQY137f
    http-types-0.12.3-D3aEnVjdeLuS27pc1eWXD
    pcre-heavy-1.0.0.2-kOalBaSd3aKHCuDuj8eWv
    profunctors-5.3-1xy35EiLpoK41syHomeyFK
    protolude-0.2.3-EsKK9736zdj3ZTboKVQrKC
    safe-exceptions-0.1.7.0-1OB3gxnI0Arp27At49iOe
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-hjsonschema/html/hjsonschema.haddock
haddock-html: /usr/share/doc/haskell-hjsonschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsonschema-1.9.0-186-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonschema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonschema
version: 1.9.0
id: hjsonschema-1.9.0-LuAMl1PC818IHtz87eN2vH
key: hjsonschema-1.9.0-LuAMl1PC818IHtz87eN2vH
license: MIT
maintainer: ian@housejeffries.com
author: Ian Grant Jeffries
homepage: https://github.com/seagreen/hjsonschema
synopsis: JSON Schema library
category: Data
abi: d38280a844760bba2f1b019b31dfd317
exposed: True
exposed-modules:
    JSONSchema.Draft4 JSONSchema.Draft4.Failure
    JSONSchema.Draft4.Schema JSONSchema.Draft4.Spec JSONSchema.Fetch
    JSONSchema.Types JSONSchema.Validator.Draft4
    JSONSchema.Validator.Draft4.Any JSONSchema.Validator.Draft4.Array
    JSONSchema.Validator.Draft4.Number
    JSONSchema.Validator.Draft4.Object
    JSONSchema.Validator.Draft4.String JSONSchema.Validator.Reference
    JSONSchema.Validator.Types JSONSchema.Validator.Utils
hidden-modules: JSONSchema.Validator.Draft4.Object.Properties
                Import
import-dirs: /usr/lib/ghc-8.6.5/site-local/hjsonschema-1.9.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hjsonschema-1.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hjsonschema-1.9.0
hs-libraries: HShjsonschema-1.9.0-LuAMl1PC818IHtz87eN2vH
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.2.0-7ArGF1xZrLvnrB0s88SSU base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hjsonpointer-1.5.0-7Ho3fUAwKrm6EdE3jNFVAC
    http-client-0.6.4-DCmpgbT5KA3LBdEx9Lt28S
    http-client-tls-0.3.5.3-59gffMozZgrJS4tvjSII2O
    http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
    pcre-heavy-1.0.0.2-6PfvXfW5o5DKDWikoNArQ2
    profunctors-5.3-1xy35EiLpoK41syHomeyFK
    protolude-0.2.3-EsKK9736zdj3ZTboKVQrKC
    safe-exceptions-0.1.7.0-1OB3gxnI0Arp27At49iOe
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-hjsonschema/html/hjsonschema.haddock
haddock-html: /usr/share/doc/haskell-hjsonschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
